# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running `nixos-help`).

{ config, lib, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
			./secrets.nix
      <home-manager/nixos>
      <nixos-hardware/dell/xps/15-9520>
      <nixos-hardware/common/gpu/nvidia/disable.nix>
    ];

  # Enable Flakes and the new command-line tool
  # nix.settings.experimental-features = [ "nix-command" "flakes" ];

  # Pick only one of the below networking options.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.
  networking.networkmanager.enable = true;  # Easiest to use and most distros use this by default.

  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "us";
  };

  # Enable CUPS to print documents.
  services.printing.enable = true;

  # Enable sound.
  sound.enable = true;

  users.users.tacocat = {
    isNormalUser = true;
    home = "/home/tacocat";
    description = "Aria Nolan";
    extraGroups = [ "wheel" "networkmanager" "audio" "video" "bluetooth" "kvm" ];
  };

  home-manager.users.tacocat = { pkgs, ... }: {
    home.packages = with pkgs; [ 
			firefox
			thunderbird
			vim
			neovim
			kitty
			wget
			tmux
			helix
			river
			git
      gcc
    ];
    home.stateVersion = "23.11";
    home.username = "tacocat";
    home.homeDirectory = "/home/tacocat";

    programs.bash = {
      enable = true;
      enableCompletion = true;
    };

    programs.git = {
      enable = true;
      userName = "Aria Nolan";
      userEmail = "aria@chytrid.xyz";
    };

    programs.kitty = {
      enable = true;
      font.name = "DejaVu Sans Mono";
      font.package = pkgs.dejavu_fonts;
    };
  };
  
	nix.settings.trusted-users = [ "tacocat" ];


  environment = {
    systemPackages = with pkgs; [
			fish
    ];
    defaultPackages = with pkgs; [
      perl
      rsync
      strace
    ];
  };

  environment.variables.EDITOR = "helix";

  # programs.firefox.package = pkgs.latest.firefox-wayland;
  # programs.firefox.enable = true;

  xdg.portal = {
    enable = true;
    wlr.enable = true;
    extraPortals = with pkgs; [
      xdg-desktop-portal-wlr
      xdg-desktop-portal-gtk
    ];
  };
  hardware.opengl.enable = true;

  # List services that you want to enable:
  # Enable the OpenSSH daemon.
  services.openssh.enable = true;
  services.pipewire.enable = true;

  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  # };


  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
  # networking.firewall.enable = false;

  # Copy the NixOS configuration file and link it from the resulting system
  # (/run/current-system/configuration.nix). This is useful in case you
  # accidentally delete configuration.nix.
  # system.copySystemConfiguration = true;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It's perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.11"; # Did you read the comment?

}

